@@ -1,9 +1,7 @@
-import formatDefault from "./formatDefault";
-import formatPrefixAuto from "./formatPrefixAuto";
-import formatRounded from "./formatRounded";
+import formatPrefixAuto from "./formatPrefixAuto.js";
+import formatRounded from "./formatRounded.js";
 
 export default {
-  "": formatDefault,
   "%": function(x, p) { return (x * 100).toFixed(p); },
   "b": function(x) { return Math.round(x).toString(2); },
   "c": function(x) { return x + ""; },
